@@ -145,24 +145,24 @@ public:
 
     _MathObject*ConstructPolynomial (void);
 
-    virtual void        Initialize          (void);
-    virtual void        Duplicate           (_Formula const *, bool deep_copy = false);
+    void        Initialize          (void);
+    void        Duplicate           (_Formula const *, bool deep_copy = false);
     void        DuplicateReference          (const _Formula*);
-    virtual BaseRef     makeDynamic         (void) const;
-    virtual BaseRef     toStr               (_hyFormulaStringConversionMode mode, _List* matchNames = nil, bool = false);
+    BaseRef     makeDynamic         (void) const;
+    BaseRef     toStr               (_hyFormulaStringConversionMode mode, _List* matchNames = nil, bool = false);
     _StringBuffer const     toRPN               (_hyFormulaStringConversionMode mode, _List* matchNames = nil);
 
-    virtual long        ObjectClass         (void);
+    long        ObjectClass         (void);
 
 
-    virtual void        ScanFForVariables   (_AVLList&l, bool includeGlobals = false, bool includeAll = false, bool includeCateg = true, bool skipMatrixAssignments = false, _AVLListX* tagger = nil, long weight = 0, long weight2 = 0) const;
-    virtual void        ScanFForType        (_SimpleList&,  int);
+    void        ScanFForVariables   (_AVLList&l, bool includeGlobals = false, bool includeAll = false, bool includeCateg = true, bool skipMatrixAssignments = false, _AVLListX* tagger = nil, long weight = 0, long weight2 = 0) const;
+    void        ScanFForType        (_SimpleList&,  int);
     /* SLKP 20100716:
             A simple utility function to retrieve all variables of a given type
      */
 
-    virtual bool        CheckFForDependence (long, bool checkAll = false);
-    virtual bool        CheckFForDependence (_AVLList const & indices, bool checkAll = false);
+    bool        CheckFForDependence (long, bool checkAll = false);
+    bool        CheckFForDependence (_AVLList const & indices, bool checkAll = false);
     
     _List&      GetList             (void) {
         return theFormula;
