@@ -130,9 +130,10 @@ const char hy_help_message [] =
 
 
 #ifdef _OPENMP
-#include "omp.h"
+    #include "omp.h"
 #endif
 
+
 //#define _COMPARATIVE_LF_DEBUG_CHECK "/Users/sergei/Desktop/lf.sequence"
 //#define _COMPARATIVE_LF_DEBUG_DUMP "/Users/sergei/Desktop/lf.sequence"
 
@@ -146,11 +147,8 @@ const char hy_help_message [] =
     #endif
 #endif
 
-_List   availableTemplateFiles,
-        availablePostProcessors,
-        loggedUserInputs;
+_List   loggedUserInputs;
 
-_Trie   availableTemplateFilesAbbreviations;
 
 _String baseArgDir,
         libArgDir;
@@ -487,7 +485,7 @@ void    DisplayHelpMessage (void) {
    }
    printf ("\n");
    //fprintf( stderr, "%s\n%s\n%s", hy_usage, hy_help_message, hy_available_cli_analyses );
-   exit (0);
+   //exit (0);
 }
             
 void    ProcessConfigStr (_String const & conf) {
@@ -529,7 +527,7 @@ void    ProcessConfigStr (_String const & conf) {
 
           case 'm':
           case 'M': {
-            hy_messages_log_name = "messages.log";
+            hy_messages_log_name = hy_messages_log_name & "messages.log";
             break;
           }
 
@@ -591,15 +589,35 @@ void    SetStatusLine               (_String s) {
 #endif
 
 }
+#ifdef _USE_EMSCRIPTEN_
+#include "emscripten.h"
+
+EM_JS(void, _jsSendStatusUpdate, (const char *status_update), {
+    // Send a message back to main thread from WebWorker
+    postMessage({
+        type: "biowasm",
+        value: {
+        text: Module.AsciiToString(status_update),
+        type : "update"
+        }
+    });
+})
+#endif
 
 //__________________________________________________________________________________
 void    SetStatusLineUser   (_String const s) {
+#ifndef _USE_EMSCRIPTEN_
   if ( has_terminal_stderr ) { // only print to terminal devices
     setvbuf(stderr, NULL, _IONBF, 0);
     BufferToConsole("\33[2K\r", stderr);
     StringToConsole(s, stderr);
     hy_need_extra_nl = true;
   }
+#else
+    if (s.nonempty()) {
+        _jsSendStatusUpdate (s.get_str());
+    }
+#endif
 }
 
 //__________________________________________________________________________________
@@ -732,7 +750,7 @@ int main (int argc, char* argv[]) {
               }
               if (thisArg == kVersionKeyword) {
                   StringToConsole(GetVersionString()); NLToConsole();
-                  exit (0);
+                  return 0;
               }
               if (thisArg == kVerboseKeyword) {
                   force_verbosity_from_cli = true;
@@ -767,20 +785,20 @@ int main (int argc, char* argv[]) {
               pathNames.Delete    (0);
               pathNames&&         &hy_lib_directory;
          }
-      } else if (thisArg.BeginsWith (path_consts[2])) {
+      } else if (thisArg.BeginsWith (path_consts[2])) { // USEPATH
           baseDir                      = thisArg.Cut(path_consts[2].length(),kStringEnd);
           hy_error_log_name            = baseDir & hy_error_log_name;
           hy_messages_log_name         = baseDir & hy_messages_log_name;
           pathNames.Delete    (0);
           pathNames&&         &baseDir;
-      } else if (thisArg.BeginsWith (path_consts[3])) {
+      } else if (thisArg.BeginsWith (path_consts[3])) { // CPU=
           system_CPU_count  = Maximum (1L, thisArg.Cut(path_consts[3].length(),kStringEnd).to_long());
-      } else if (thisArg.BeginsWith (path_consts[4])) {
+      } else if (thisArg.BeginsWith (path_consts[4])) { // ENV=
           hy_env::cli_env_settings = thisArg.Cut(path_consts[4].length(),kStringEnd);
       }
-      else
-      //argFile = thisArg;
-      positional_arguments && &thisArg;
+      else {
+          positional_arguments && &thisArg;
+      }
     }
     
     GlobalStartup();
@@ -972,7 +990,9 @@ int main (int argc, char* argv[]) {
     
     GlobalShutdown              ();
     
-
+    
+    fflush (stdout);
+    
 
 #ifdef __MINGW32__
   fflush (stdout);
@@ -985,6 +1005,7 @@ int main (int argc, char* argv[]) {
     }
 #endif
 
+    return 0;
 }
 
 #endif
